<?php 
/*
Plugin Name: TNG Google Badge Widget
Plugin URI: http://jontang.se/tng-google-badge-widget
Description: A plugin displaying a Google+ badge.
Version: 1.0
Author: Jon Täng
Author URI: http://jontang.se
License: GPL2
*/

load_plugin_textdomain('tng_google_badge_widget', false, basename( dirname( __FILE__ ) ) . '/languages' );
// register Foo_Widget widget
add_action( 'widgets_init', create_function( '', 'register_widget( "tng_google_badge_widget" );' ) );

/**
 * Adds Foo_Widget widget.
 */
class TNG_Google_Badge_Widget extends WP_Widget {
	
	public $lang;

	/**
	 * Register widget with WordPress.
	 */
	function TNG_Google_Badge_Widget() {
		$widget_ops = array( 
			'classname' => 'tng_google_badge_widget', 
			'description' => __( 'A Widget for displaying a Google+ badge.', 'tng_google_badge_widget' ) );
		$this->WP_Widget( 'tng_google_badge_widget', __( 'TNG Google Badge Widget', 'tng_google_badge_widget' ), $widget_ops );
		$this->alt_option_name = 'tng_google_badge_widget';
		
		add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
	}
	
	/**
	 *	Enqueue Google PlusOne API 
	 */
	function enqueue_scripts(){
		/*wp_enqueue_script( 'google-plusone', 'https://apis.google.com/js/plusone.js' );
		$lang = array( 'lang' => $this->lang );
		if ( 'en' != $this->lang )
			wp_localize_script( 'google-plusone', 'gapi', $lang );*/
		add_action( 'wp_footer', array( $this, 'scripts' ) );
	}
	
	function scripts() {
		//$lang = $this->lang;
	/*?>
		<script type="text/javascript" src="https://apis.google.com/js/plusone.js">
		<?php if ( 'en' != $lang ) : ?>
			{lang: '<?php echo $lang; ?>'}
		<?php endif; ?>
		</script>
	<?php*/
	?>
		<script type="text/javascript">
		var language = '<?php echo $this->lang; ?>';
		if ( 'en' != language ) {
			window.___gcfg = {lang: language};
		}

		(function() {
			var po = document.createElement('script'); po.type = 'text/javascript'; po.async = true;
			po.src = 'https://apis.google.com/js/plusone.js';
			var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(po, s);
		})();
		</script>
	<?php	
	}
	/**
	 * Front-end display of widget.
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	function widget( $args, $instance ) {
		extract( $args );
		extract( $instance );
		
		$this->lang = $lang;
		
		if ( !isset($google_id) )
			return;
		
		$output = '<div id="gplus" class="widget-content"><div class="'. $class .'" ';
		$output .= 'data-href="https://plus.google.com/'. $google_id .'" ';
		//$output .= 'data-href="'. $href .'" ';
		$output .= 'data-width="'. $width .'" ';
		
		$output .= 'data-layout="'. $layout .'" ';
		$output .= 'data-theme="'. $theme .'" ';
		
		if ( !$showcoverphoto )
			$output .= 'data-showcoverphoto="false" ';
		
		if ( !$showtagline )
			$output .= 'data-showtagline="false" ';
		
		if ( 'g-person' == $class )
			$output .= 'data-rel="author"';
		if ( 'g-page' == $class )
			$output .= 'data-rel="publisher"';
		
		$output .= '></div></div>';
		echo '<style>#gplus, #gplus div, #gplus iframe, #widget_bounds { max-width: '.$width.'px !important; width:100% !important;}</style>';
		echo '';
		
		echo $before_widget;
		if ( ! empty( $title ) ) 
			echo $before_title . $title . $after_title;
		
		echo $output;
		
		echo $after_widget;
	}
	
	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title']	= strip_tags( $new_instance['title'] );
		$instance['class']	= strip_tags( $new_instance['class'] );
		$instance['google_id']	= strip_tags( $new_instance['google_id'] );
		//$instance['href']	= strip_tags( $new_instance['href'] );
		$instance['layout']	= strip_tags( $new_instance['layout'] );
		$instance['theme']	= strip_tags( $new_instance['theme'] );
		$instance['showcoverphoto']	= strip_tags( $new_instance['showcoverphoto'] );
		$instance['showtagline']	= strip_tags( $new_instance['showtagline'] );
		$instance['width']	= strip_tags( $new_instance['width'] );
		$instance['lang']	= strip_tags( $new_instance['lang'] );

		return $instance;
	}

	/**
	 * Back-end widget form.
	 *
	 * @param array $instance Previously saved values from database.
	 */
	function form( $instance ) {
		$title	= isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : __('Follow on Google+', 'tng_google_badge_widget');
		$class	= isset( $instance['class'] ) ? esc_attr( $instance['class'] ) : 'g-page';
		$google_id = isset( $instance['google_id'] ) ? esc_attr( $instance['google_id'] ) : '';
		//$href	= isset( $instance['href'] ) ? esc_url( $instance['href'] ) : '';
		$layout	= isset( $instance['layout'] ) ? esc_attr( $instance['layout'] ) : 'portrait';
		$theme	= isset( $instance['theme'] ) ? esc_attr( $instance['theme'] ) : 'light';
		$showcoverphoto	= isset( $instance['showcoverphoto'] ) ? esc_attr( $instance['showcoverphoto'] ) : true;
		$showtagline	= isset( $instance['showtagline'] ) ? esc_attr( $instance['showtagline'] ) : true;
		$width	= isset( $instance['width'] ) ? (int)( $instance['width'] ) : 370;
		$lang	= isset( $instance['lang'] ) ? esc_attr( $instance['lang'] ) : 'en';
		?>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Widget title:', 'tng_google_badge_widget' ); ?></label> 
			<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>
		<p>
			<?php $classes = array( 'g-person' => __('Person', 'tng_google_badge_widget' ), 'g-page' => __('Page', 'tng_google_badge_widget' ), 'g-community' => __('Community', 'tng_google_badge_widget' ) ); ?>
			<label for="<?php echo $this->get_field_id( 'class' ); ?>"><?php _e( 'Badge type:', 'tng_google_badge_widget' ); ?></label> 
			<select class="widefat" id="<?php echo $this->get_field_id( 'class' ); ?>" name="<?php echo $this->get_field_name( 'class' ); ?>">
			<?php foreach ( $classes as $v => $l ) : ?>
				<option value="<?php echo esc_attr( $v ); ?>" <?php selected( $class, $v, true ); ?>><?php echo esc_attr( $l ); ?></option>
			<?php endforeach; ?>
			</select>
		</p>
		<p>
			<label for="<?php echo $this->get_field_id( 'google_id' ); ?>"><?php _e( 'Google ID:', 'tng_google_badge_widget' ); ?></label> 
			<input class="widefat" id="<?php echo $this->get_field_id( 'google_id' ); ?>" name="<?php echo $this->get_field_name( 'google_id' ); ?>" type="text" value="<?php echo esc_attr( $google_id ); ?>" />
		</p>
		
		<p>
			<?php $layouts = array( 'landscape' => __('Landscape (width: 273-450 px)', 'tng_google_badge_widget' ), 'portrait' => __('Portrait (width: 180-450 px)', 'tng_google_badge_widget' ) ); ?>
			<label for="<?php echo $this->get_field_id( 'layout' ); ?>"><?php _e( 'Layout:', 'tng_google_badge_widget' ); ?></label> 
			<select class="widefat" id="<?php echo $this->get_field_id( 'layout' ); ?>" name="<?php echo $this->get_field_name( 'layout' ); ?>">
			<?php foreach ( $layouts as $v => $l ) : ?>
				<option value="<?php echo esc_attr( $v ); ?>" <?php selected( $layout, $v, true ); ?>><?php echo esc_attr( $l ); ?></option>
			<?php endforeach; ?>
			</select>
		</p>
		
		<p>
			<?php $bools = array( true => __('True', 'tng_google_badge_widget' ), false => __('False', 'tng_google_badge_widget' ) ); ?>
			<label for="<?php echo $this->get_field_id( 'showcoverphoto' ); ?>"><?php _e( 'Show coverphoto:', 'tng_google_badge_widget' ); ?></label> 
			<select class="widefat" id="<?php echo $this->get_field_id( 'showcoverphoto' ); ?>" name="<?php echo $this->get_field_name( 'showcoverphoto' ); ?>">
			<?php foreach ( $bools as $v => $l ) : ?>
				<option value="<?php echo esc_attr( $v ); ?>" <?php selected( $showcoverphoto, $v, true ); ?>><?php echo esc_attr( $l ); ?></option>
			<?php endforeach; ?>
			</select>
		</p>
		
		<p>
			<?php //$bools = array( 1 => 'True', 0 => 'False' ); ?>
			<label for="<?php echo $this->get_field_id( 'showtagline' ); ?>"><?php _e( 'Show tagline:', 'tng_google_badge_widget' ); ?></label> 
			<select class="widefat" id="<?php echo $this->get_field_id( 'showtagline' ); ?>" name="<?php echo $this->get_field_name( 'showtagline' ); ?>">
			<?php foreach ( $bools as $v => $l ) : ?>
				<option value="<?php echo esc_attr( $v ); ?>" <?php selected( $showtagline, $v, true ); ?>><?php echo esc_attr( $l ); ?></option>
			<?php endforeach; ?>
			</select>
		</p>
		
		<p>
			<?php $themes = array( 'light' => __('Light', 'tng_google_badge_widget' ), 'dark' => __('Dark', 'tng_google_badge_widget' ) ); ?>
			<label for="<?php echo $this->get_field_id( 'theme' ); ?>"><?php _e( 'Theme:', 'tng_google_badge_widget' ); ?></label> 
			<select class="widefat" id="<?php echo $this->get_field_id( 'theme' ); ?>" name="<?php echo $this->get_field_name( 'theme' ); ?>">
			<?php foreach ( $themes as $v => $l ) : ?>
				<option value="<?php echo esc_attr( $v ); ?>" <?php selected( $theme, $v, true ); ?>><?php echo esc_attr( $l ); ?></option>
			<?php endforeach; ?>
			</select>
		</p>
		
		<p>
			<label for="<?php echo $this->get_field_id( 'width' ); ?>"><?php _e( 'Width:', 'tng_google_badge_widget' ); ?></label> 
			<input class="widefat" id="<?php echo $this->get_field_id( 'width' ); ?>" name="<?php echo $this->get_field_name( 'width' ); ?>" type="text" value="<?php echo esc_attr( $width ); ?>" />
		</p>
		
		<p>
			<?php $langs = array( 'sv' => __('Swedish', 'tng_google_badge_widget'), 'no' => __('Norwegian', 'tng_google_badge_widget'), 'en' => __('English', 'tng_google_badge_widget') ); ?>
			<label for="<?php echo $this->get_field_id( 'lang' ); ?>"><?php _e( 'Language:', 'tng_google_badge_widget' ); ?></label> 
			<select class="widefat" id="<?php echo $this->get_field_id( 'lang' ); ?>" name="<?php echo $this->get_field_name( 'lang' ); ?>">
			<?php foreach ( $langs as $v => $l ) : ?>
				<option value="<?php echo esc_attr( $v ); ?>" <?php selected( $lang, $v, true ); ?>><?php echo esc_attr( $l ); ?></option>
			<?php endforeach; ?>
			</select>
		</p>
		
		<?php 
	}

} // class Foo_Widget